from clickcounter.providers._base import BaseProvider


REGISTER_URL = 'https://www.shorturl.at/shortener.php'
ANALYTICS_URL_TEMPLATE = 'https://www.shorturl.at/url-total-clicks.php?u={}'
TRACK_URL_TEMPLATE = "https://shorturl.at/{}"


class ShortUrlAt(BaseProvider):
    def register_url(self, url):
        self.session.get('https://www.shorturl.at/')
        response = self.session.post(REGISTER_URL, data={"u": url}, headers={
                                     'content-type': 'application/x-www-form-urlencoded'}).text

        url_id = response.split(
            "url-total-clicks.php?u=shorturl.at/")[1].split('">')[0]
        return TRACK_URL_TEMPLATE.format(url_id)

    def get_visits(self, track_url):
        analytics_url = ANALYTICS_URL_TEMPLATE.format(
            track_url.split("https://")[-1])
        response = self.session.get(analytics_url).text
        return int(response.split('<div class="squarebox"><b>')[1].split("<")[0])



from clickcounter import providers
import argparse
import logging
import json
logging.basicConfig(level=logging.INFO)


_VALID_COMMANDS = ["register", "get", "getall"]


def cli():
    parser = argparse.ArgumentParser()
    parser.add_argument('command', type=str,
                        help="valid commands: " + ', '.join(_VALID_COMMANDS))
    parser.add_argument('--provider',
                        default="shorturl.at", type=str, help="defaults to shorturl.at")
    parser.add_argument('--username',  default=None, type=str,
                        help="some providers require login")
    parser.add_argument('--password', default=None, type=str,
                        help="some providers require login")
    parser.add_argument('--url', default=None, type=str,
                        help="used during register")
    parser.add_argument('--trackurl',  default=None,
                        type=str, help="used during get")
    try:
        args = parser.parse_args()

        provider = providers.get(args.provider)
        if provider is None:
            logging.error(
                f"unsupported provider: '{args.provider}', valid providers: {list(providers.keys())}")
            exit(1)
        provider = provider()
        provider.login(args.username, args.password)

        if args.command == "register":
            track_url = provider.register_url(args.url)
            print(track_url)

        elif args.command == "get":
            track_url_count = provider.get_visits(args.trackurl)
            print(track_url_count)

        elif args.command == "getall":
            track_url_counts = provider.get_all_visits()
            print(json.dumps(track_url_counts))
        else:
            logging.error(
                f"unsupported command: '{args.command}', valid commands: {_VALID_COMMANDS}")
            exit(1)
    except:
        parser.print_help()
        raise


if __name__ == "__main__":
    cli()



from clickcounter.providers.shorturl_at import ShortUrlAt
from clickcounter.providers.linkclickcounter_com import LinkClickCounterCom

providers = {
    "shorturl.at": ShortUrlAt,
    "linkclickcounter.com": LinkClickCounterCom
}

_default_provider_singleton = ShortUrlAt()

register_url = _default_provider_singleton.register_url

get_visits = _default_provider_singleton.get_visits

make_visit = _default_provider_singleton.make_visit



import lxml.html as lh


def extract_table_rows_from_html_string(html_string):
    doc = lh.fromstring(html_string)
    tr_elements = doc.xpath('//tr')
    keys = []
    for cell in tr_elements[0]:
        val = cell.text_content()
        keys.append(val.strip())
    rows = []
    for raw_row in tr_elements[1:]:
        row = {}
        for key, cell in zip(keys, raw_row):
            if not key:
                continue
            val = cell.text_content()
            row[key] = val
        rows.append(row)
    return rows



import time
from clickcounter.providers._base import BaseProvider
from clickcounter import _utils


REGISTER_URL = 'https://www.linkclickcounter.com/createShortURL.php'

LOGIN_URL = 'https://www.linkclickcounter.com/userAccount.php'
ANALYTICS_URL_TEMPLATE = 'https://www.linkclickcounter.com/monitoring.php'


class LinkClickCounterCom(BaseProvider):
    def login(self, email, password):
        response = self.session.post(LOGIN_URL, data={
            "email": email,
            "password": password,
            "rememberMe": 1,
            "loginSubmit": "Sign In"
        }, headers={
            'content-type': 'application/x-www-form-urlencoded'})
        response.raise_for_status()

    def register_url(self, url):
        self.session.get(ANALYTICS_URL_TEMPLATE)
        self.session.post(REGISTER_URL, data={
            "inner_url": url,
            "url_tag_name": None,
            "shortened_domain": 19,
            "innerURLSubmit": "START MONITORING !"
        }, headers={
            'content-type': 'application/x-www-form-urlencoded'}).text

        rows = self._get_raw_rows()
        selected_row = [r for r in rows if r['Monitored URL'] == url]
        if not selected_row:
            raise RuntimeError("error creating monitoring url")
        return selected_row[0]['Shorten URL']

    def get_visits(self, track_url):
        all_visits = self.get_all_visits()
        track_url_count = all_visits.get(track_url)
        if track_url_count is None:
            raise KeyError(f"{track_url} not found amongst rows: {all_visits}")
        return track_url_count

    def get_all_visits(self):
        rows = self._get_raw_rows()
        return {r['Shorten URL']: int(r['Clicks Counter']) for r in rows}

    def _get_raw_rows(self, max_tries=5):
        response = None
        for try_number in range(1, max_tries+1):
            try:
                response = self.session.get(ANALYTICS_URL_TEMPLATE)
                return _utils.extract_table_rows_from_html_string(response.content)
            except:
                if try_number >= max_tries:
                    raise Exception(
                        f"Error during fetch of monitoring rows, last response: {response}")
            time.sleep(try_number)



import requests


class BaseProvider:
    headers = {}

    def __init__(self):
        self.session = requests.session()
        self.session.headers.update(self.headers)

    def login(self, *args, **kwargs):
        pass

    def register_url(self, *args, **kwargs):
        raise NotImplementedError()

    def get_visits(self, *args, **kwargs):
        raise NotImplementedError()

    def get_all_visits(self, *args, **kwargs):
        raise NotImplementedError()

    def make_visit(self, track_url):
        return self.session.get(track_url)
